#!/bin/bash

## pidWatchdog.sh
##
## Monitors the status of the PID specified in the provided PID_FILE.
## - If the PID running (or the PID file doesn't exist), do nothing.
## - If the PID is not running, restart the app by running STARTUP_SCRIT.
##
## USAGE: pidWatchdog.sh <APP_NAME> <PID_FILE> <STARTUP_SCRIPT>

# Check input parameters
if [[ -z $1 || -z $2 || -z $3 ]]
then
  echo "USAGE: pidWatchdog.sh <APP_NAME> <PID_FILE> <STARTUP_SCRIPT>"
  exit 1
fi

APP_NAME=$1
PID_FILE=$2
STARTUP_SCRIPT=$3

# Function to send email
send_email () {
/usr/sbin/sendmail -t <<EOF
To: shoban_sriram@genpt.com
From: $USER@$(hostname)
Subject: $APP_NAME - Restart alert
Content-Type: text/html; charset=ISO-8859-1
Content-Transfer-Encoding: 8bit
<html>
<p>$APP_NAME has shutdown unexpectedly and has been restarted.</p>
</html>
EOF
}

# Does the PID file exist?
if [[ ! -f $PID_FILE ]]
then
  # No PID file present -> presumed to be cleanly shut down, and no action needed
  echo "App is cleanly shut down (no PID file found)."
else
  # PID file present -> verify PID is active
  if [[ $(pgrep --pidfile "$PID_FILE" | grep -v grep -c) -gt 0 ]]
  then
    # PID is active -> no action needed
    echo "PID $(cat "$PID_FILE") is active."
  else
    # PID is not active -> restart app and send alert email
    echo "PID $(cat "$PID_FILE") is not active. Restarting app."
    eval "$STARTUP_SCRIPT"
    send_email
  fi
fi